<?php
 /**
  * 
  * @package    BizReview - Business and google Place Review WordPress Plugin
  * @version    1.0
  * @author     ThemeAtelier
  * @Websites: https://themeatelier.net/
  *
  */
  if( ! defined( 'ABSPATH' ) ) {
    die( BIZREVIEW_ALERT_MSG );
  }

// Google api

add_action( 'init', 'bizreview_google_api' );
function bizreview_google_api() {

  $option = get_option( 'bizreview_options' );

	$args = array(
		'apikey'  => $option['gookey'] ,
		'placeid' => $option['gplaceid']
	);

	$obj = new BizReview_Google_API( $args );

	return $obj->get_place_data();

}

// yelp api
function bizreview_get_yelp_data() {

  $option = get_option( 'bizreview_options' );

  $args = array(
    'apikey'  => $option['yelpapikey'] ,
    'busid' => $option['busid']
  );

  $obj = new BizReview_Yelp_API( $args );

  return $obj->get_yelp_data();


}

/**
 * Custom Post type  
 */

function bizreview_review_posttype() {
    // Custom Reviews post type
    register_post_type( 'bizreview',
        array(
            'labels' => array(
            'name' => esc_html__( 'Custom Reviews', 'bizreview' ),
            'singular_name' => esc_html__( 'Custom Review', 'bizreview' )
            ),
            'public' => true,
            'publicly_queryable' => true,
            'query_var'=> true,
            'has_archive' => true,
            'show_in_menu' => false,
            'rewrite' => array( 'slug' => 'bizreview-custom-review' ),
            'supports' => array('title')
        )
    );

    // Taxonomy

  $labels = array(
    'name'              => esc_html__( 'Categories', 'bizreview' ),
    'singular_name'     => esc_html__( 'Categories', 'bizreview' ),
  );

  $args = array(
    'hierarchical'      => true,
    'labels'            => $labels,
    'show_ui'           => true,
    'show_admin_column' => true,
    'query_var'         => false,
    'rewrite'           => array( 'slug' => 'review-category' ),
  );

  register_taxonomy( 'review_category', array( 'bizreview' ), $args );


  // Post type for Review badges
    register_post_type( 'reviewbadges',
        array(
            'labels' => array(
            'name' => esc_html__( 'Review Badges', 'bizreview' ),
            'singular_name' => esc_html__( 'Review Badges', 'bizreview' )
            ),
            'public' => true,
            'has_archive' => true,
            'show_in_menu' => false,
            'rewrite' => array( 'slug' => 'bizreview-badges' ),
            'supports' => array('title')
        )
    );

  // Post type for google review
    register_post_type( 'google_review',
        array(
            'labels' => array(
            'name' => esc_html__( 'Google Review', 'bizreview' ),
            'singular_name' => esc_html__( 'Google Review', 'bizreview' )
            ),
            'public' => true,
            'has_archive' => true,
            'show_in_menu' => false,
            'rewrite' => array( 'slug' => 'google-review' ),
            'supports' => array('title')
        )
    );

}
add_action( 'after_setup_theme', 'bizreview_review_posttype' );

/**
 * Get custom review categories
 *
 *
 */

function bizreview_custom_review_cat() {

  $terms = get_terms( array(
     'taxonomy' => 'review_category',
      'hide_empty' => false,
  ) );


  $cat = ['nocat' => 'Select Category'];

  if( !empty( $terms ) ) {

    foreach( $terms as $term ) {

        $cat[$term->slug] = $term->name;

    }

  }

  return  $cat;

}


/**
 * Get google reviews
 *
 *
 */
function bizreview_get_google_reviews( $order = 'DESC' ) {
// DESC , ASC

  $args = array(
    'post_type' => 'google_review',
    'order' => esc_html( $order ),
    'posts_per_page' => '-1'
  );

  $posts = get_posts( $args );

  $data = array();

  foreach( $posts  as $value ) {

    $data[] = array(
      'author_name' => get_post_meta( $value->ID, 'author_name', true ),
      'author_url' => get_post_meta( $value->ID, 'author_url', true ),
      'profile_photo_url' => get_post_meta( $value->ID, 'profile_photo_url', true ),
      'rating' =>  get_post_meta( $value->ID, 'rating', true ),
      'relative_time_description' => get_post_meta( $value->ID, 'relative_time_description', true ),
      'text' => get_post_meta( $value->ID, 'text', true ),
      'time' => get_post_meta( $value->ID, 'time', true )
    );

  }

  return $data;

}

/**
 * Rating helper function
 *
 *
 */

function bizreview_star_review( $rating ) {

    $j = 0;
    for( $i = 0; $i <= 4; $i++ ) {
      $j++;

      if( $rating  >= $j   || $rating  == '5'   ) {
         echo '<i class="fas fa-star"></i>';
      }elseif( $rating < $j && $rating  > $i )
      {
         echo '<i class="fas fa-star-half-alt"></i>';                     

      } else {
         echo '<i class="far fa-star"></i>';
      }
    }

}

/**
 * Google Place info
 *
 *
 */

function bizreview_place_info() {
   
  $data = get_option( 'bizreview_place_info' );

  $data = json_decode( $data, true );

  if( is_array( $data ) && !empty( $data ) ):
  ?>
  <div class="biz-col-sm-12 text-center">
    <div class="place-info p-20px m-50px-b">
        <?php 
        if( !empty( $data['icon'] ) ):
        ?>
        <img src="<?php echo esc_url( $data['icon'] ); ?>" alt="<?php echo esc_attr( $data['name'] ); ?>" />
        <?php
        endif; 
        //
        if( !empty( $data['name'] ) ):
        ?>
       <h4><a href="<?php echo esc_url( $data['url'] ); ?>" target="_blank"><?php echo esc_html( $data['name'] ); ?></a></h4>
       <?php
        endif;
       //
       if( !empty( $data['formatted_address'] ) ):
       ?>
       <p><?php echo esc_html__( 'Address: ', 'bizreview' ).esc_html( $data['formatted_address'] ); ?></p>
       <?php 
        endif;
        //
        if( !empty( $data['formatted_phone_number'] ) ):
       ?>
       <p><?php echo esc_html__( 'Phone Number: ', 'bizreview' ).esc_html( $data['formatted_phone_number'] ); ?></p>
       <?php 
        endif;

        //
        if( ! empty( $data['rating'] ) ) {

          echo '<div class="color-google">';
            echo '<strong>'.$data['rating'].'</strong> ';
            bizreview_star_review( $data['rating'] );
          echo '</div>';
        }

        //
        if( !empty( $data['user_ratings_total'] ) ):
       ?>
       <p><?php echo sprintf( esc_html__( 'Based on %s reviews', 'bizreview' ), $data['user_ratings_total'] );  ?></p>

       <?php
        endif;          
       ?>
      <div class="powered-by color-google">
        <p><strong><?php esc_html_e( 'Powered by google.', 'bizreview' ); ?></strong></p>
      </div>

    </div>
  </div>
  <?php
    endif;
}

/**
 * Widget Google Place info
 *
 *
 */

function bizreview_widget_google_place_info( ) {

  $data = get_option( 'bizreview_place_info' );

  $data = json_decode( $data, true );

  ?>
  <div class="widget-place-info text-center single-wreview-item p-15px">
      <?php 
      if( !empty( $data['icon'] ) ):
      ?>
      <img src="<?php echo esc_url( $data['icon'] ); ?>" alt="<?php echo esc_attr( $data['name'] ); ?>" />
      <?php
      endif;
      //
      if( !empty( $data['name'] ) ):
      ?>
     <h4><a href="<?php echo esc_url( $data['url'] ); ?>" target="_blank"><?php echo esc_html( $data['name'] ); ?></a></h4>
     <?php
      endif;
     //
     if( !empty( $data['formatted_address'] ) ):
     ?>
     <p><?php echo esc_html__( 'Address: ', 'bizreview' ).esc_html( $data['formatted_address'] ); ?></p>
     <?php 
      endif;
      //
      if( !empty( $data['formatted_phone_number'] ) ):
     ?>
     <p><?php echo esc_html__( 'Phone Number: ', 'bizreview' ).esc_html( $data['formatted_phone_number'] ); ?></p>
     <?php 
      endif;
     ?>
     
     <?php
     //
     if( ! empty( $data['rating'] ) ) {
        echo '<div class="widget-rating color-google">';
          echo '<strong>'.$data['rating'].'</strong> ';
          bizreview_star_review( $data['rating'] );
        echo '</div>';
     }
       
      //
      if( !empty( $data['user_ratings_total'] ) ):             
     ?>
     <p><?php echo sprintf( esc_html__( 'Based on %s reviews', 'bizreview' ), $data['user_ratings_total'] );  ?></p>
      <?php 
      endif;
      ?>
  </div>
  <?php

}

/**
 * Get Badges for admin badges list
 *
 *
 */

function bizreview_get_badges() {

  $args = array(
    'post_type'      => 'reviewbadges',
    'posts_per_page' => '-1',
  );


  $data = get_posts( $args );


  return $data;
  
}


/**
 * custom review pagination
 *
 *
 */

  function bizreview_custom_review_pagination( $query_object ) {

    
    if( $query_object->have_posts() ) {

      echo '<div class="biz-pagination">';

      $big = 999999999; // need an unlikely integer
      echo paginate_links( array(
         'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
         'format' => '?paged=%#%',
         'current' => max( 1, get_query_var('paged') ),
         'total' => $query_object->max_num_pages
      ) );

      echo '</div>';

    }

  }


/**
 * Google Review Templates init
 *
 *
 */

function bizreview_google_review_template_init( $args ) {


  $reviewObj = new Google_Review_Template( $args );

    // Style Switch
    switch ( $args['atts']['style'] ) {
        case '1':
            $reviewObj->biz_google_review_template_s1();
            break;
        case '2':
            $reviewObj->biz_google_review_template_s2();
            break;
        case '3':
            $reviewObj->biz_google_review_template_s3();
            break;
        case '4':
            $reviewObj->biz_google_review_template_s4();
            break;
        case '5':
            $reviewObj->biz_google_review_template_s5();
            break;
        case '6':
            $reviewObj->biz_google_review_template_s6();
            break;
        case '7':
            $reviewObj->biz_google_review_template_s7();
            break;
        case '8':
            $reviewObj->biz_google_review_template_s8();
            break;
        case '9':
            $reviewObj->biz_google_review_template_s9();
            break;
        case '10':
            $reviewObj->biz_google_review_template_s10();
            break;
        case '11':
            $reviewObj->biz_google_review_template_s11();
            break;
        case '12':
            $reviewObj->biz_google_review_template_s12();
            break;
        case '13':
            $reviewObj->biz_google_review_template_s13();
            break;
        case '14':
            $reviewObj->biz_google_review_template_s14();
            break;
        default:
            $reviewObj->biz_google_review_template_s1();
            break;
    }


}

/**
 * Custom Review Templates init
 *
 *
 */

function bizreview_custom_review_template_init( $args ) {


  $reviewObj = new Custom_Review_Template( $args );

    if( !empty( $args['style'] ) ) {

    // Style Switch
    switch ( $args['style'] ) {
        case '1':
            $reviewObj->biz_custom_review_template_s1();
            break;
        case '2':
            $reviewObj->biz_custom_review_template_s2();
            break;
        case '3':
            $reviewObj->biz_custom_review_template_s3();
            break;
        case '4':
            $reviewObj->biz_custom_review_template_s4();
            break;
        case '5':
            $reviewObj->biz_custom_review_template_s5();
            break;
        case '6':
            $reviewObj->biz_custom_review_template_s6();
            break;
        case '7':
            $reviewObj->biz_custom_review_template_s7();
            break;
        case '8':
            $reviewObj->biz_custom_review_template_s8();
            break;
        case '9':
            $reviewObj->biz_custom_review_template_s9();
            break;
        case '10':
            $reviewObj->biz_custom_review_template_s10();
            break;
        case '11':
            $reviewObj->biz_custom_review_template_s11();
            break;
        case '12':
            $reviewObj->biz_custom_review_template_s12();
            break;
        case '13':
            $reviewObj->biz_custom_review_template_s13();
            break;
        case '14':
            $reviewObj->biz_custom_review_template_s14();
            break;
        default:
            $reviewObj->biz_custom_review_template_s1();
            break;
    }

  }

}

/**
 * Facebook Review Templates init
 *
 *
 */

function bizreview_facebook_review_template_init( $args ) {


  $reviewObj = new Facebook_Review_Template( $args );

    // Style Switch
    switch ( $args['atts']['style'] ) {
        case '1':
            $reviewObj->biz_facebook_review_template_s1();
            break;
        case '2':
            $reviewObj->biz_facebook_review_template_s2();
            break;
        case '3':
            $reviewObj->biz_facebook_review_template_s3();
            break;
        case '4':
            $reviewObj->biz_facebook_review_template_s4();
            break;
        case '5':
            $reviewObj->biz_facebook_review_template_s5();
            break;
        case '6':
            $reviewObj->biz_facebook_review_template_s6();
            break;
        case '7':
            $reviewObj->biz_facebook_review_template_s7();
            break;
        case '8':
            $reviewObj->biz_facebook_review_template_s8();
            break;
        case '9':
            $reviewObj->biz_facebook_review_template_s9();
            break;
        case '10':
            $reviewObj->biz_facebook_review_template_s10();
            break;
        case '11':
            $reviewObj->biz_facebook_review_template_s11();
            break;
        case '12':
            $reviewObj->biz_facebook_review_template_s12();
            break;
        case '13':
            $reviewObj->biz_facebook_review_template_s13();
            break;
        case '14':
            $reviewObj->biz_facebook_review_template_s14();
            break;
        default:
            $reviewObj->biz_facebook_review_template_s1();
            break;
    }


}

/**
 * Yelp Review Templates init
 *
 *
 */

function bizreview_yelp_review_template_init( $args ) {


  $reviewObj = new Yelp_Review_Template( $args );

    // Style Switch
    switch ( $args['atts']['style'] ) {
        case '1':
            $reviewObj->biz_yelp_review_template_s1();
            break;
        case '2':
            $reviewObj->biz_yelp_review_template_s2();
            break;
        case '3':
            $reviewObj->biz_yelp_review_template_s3();
            break;
        case '4':
            $reviewObj->biz_yelp_review_template_s4();
            break;
        case '5':
            $reviewObj->biz_yelp_review_template_s5();
            break;
        case '6':
            $reviewObj->biz_yelp_review_template_s6();
            break;
        case '7':
            $reviewObj->biz_yelp_review_template_s7();
            break;
        case '8':
            $reviewObj->biz_yelp_review_template_s8();
            break;
        case '9':
            $reviewObj->biz_yelp_review_template_s9();
            break;
        case '10':
            $reviewObj->biz_yelp_review_template_s10();
            break;
        case '11':
            $reviewObj->biz_yelp_review_template_s11();
            break;
        case '12':
            $reviewObj->biz_yelp_review_template_s12();
            break;
        case '13':
            $reviewObj->biz_yelp_review_template_s13();
            break;
        case '14':
            $reviewObj->biz_yelp_review_template_s14();
            break;
        default:
            $reviewObj->biz_yelp_review_template_s1();
            break;
    }


}

// Date Format
function biz_date_format( $getdate ) {
	
	$bizrev_options = get_option( 'bizreview_options' );

	$dateformat = !empty( $bizrev_options['dateformat'] ) ? $bizrev_options['dateformat'] : 'F j, Y';

	$date = date_i18n( $dateformat , strtotime( $getdate ) );
	
	return $date;
		
}


/**
 * Visitor statistics database table
 * 
 */

global $biz_db_table_version;

$biz_db_table_version = '1.0';



//  Create visitor statistics table

function biz_visitor_statistics_db_table_create() {

  global $wpdb;
  global $biz_db_table_version;

  $table_name = $wpdb->prefix . 'biz_visitor_statistics';

  $charset_collate = $wpdb->get_charset_collate();

  $sql = "CREATE TABLE $table_name (
    id mediumint(9) NOT NULL AUTO_INCREMENT,
    time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
    statistics_id text NOT NULL,
    meta_key text NOT NULL,
    meta_value text NOT NULL,
    PRIMARY KEY  (id)
  ) $charset_collate;";

  require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
  dbDelta( $sql );

  add_option( 'biz_db_table_version', $biz_db_table_version );



}

// Insert visitor statistics table data

function biz_insert_visitor_statistics_data( $data ) {
  global $wpdb;


  $table_name = $wpdb->prefix . 'biz_visitor_statistics';


  $default = array(
      'time' => current_time( 'mysql' ), 
      'statistics_id' => '', 
      'meta_key' => '', 
      'meta_value' => '', 
    );


  $dbData = wp_parse_args( $data, $default );


  $wpdb->insert( 
    $table_name, 
    $dbData
  );


}

// Update visitor statistics table data
function biz_visitor_statistics_update( $id, $key, $value ) {

  global $wpdb;

  $table_name = $wpdb->prefix . 'biz_visitor_statistics';


  $data = array(
    'meta_key' => $key,
    'meta_value' => $value
  );


  $where = array(
    'statistics_id' => $id
  );


  $wpdb->update( $table_name, $data, $where, $format = null, $where_format = null );

}




// Get table row 
function biz_get_table_row( $table, $col, $value ) {

  global $wpdb;

  $table_name = $wpdb->prefix . $table;

  return $wpdb->get_row( "SELECT * FROM $table_name WHERE $col = '$value' ", ARRAY_N );

}

// Visitor count handling
function biz_visitor_count() {


  $day    = date('z');
  $week   = date('W');
  $month  = date('n');
  $year   = date( 'Y' );


  $day_statistics_id    = $day.'_'.$year;
  $week_statistics_id   = $week.'_'.$month.'_'.$year;
  $month_statistics_id  = $month.'_'.$year;
  $year_statistics_id   = $year;



  $day_get_row = biz_get_table_row( 'biz_visitor_statistics', 'statistics_id', $day_statistics_id );
  $week_get_row = biz_get_table_row( 'biz_visitor_statistics', 'statistics_id', $week_statistics_id );
  $month_get_row = biz_get_table_row( 'biz_visitor_statistics', 'statistics_id', $month_statistics_id );
  $year_get_row = biz_get_table_row( 'biz_visitor_statistics', 'statistics_id', $year_statistics_id );


  // Update day counter
  if( null !== $day_get_row ) {

    if( $day_statistics_id == $day_get_row[2] ) {

        $c = absint( $day_get_row[4] );

        $count =  $c + 1;

        biz_visitor_statistics_update( $day_statistics_id, 'day_visitors', $count );
    }
    
  } else {

    biz_insert_visitor_statistics_data( array(
      'statistics_id' => $day_statistics_id,
      'meta_key' => 'day_visitors',
      'meta_value' => 1
    ) );


  }


  // update week counter
  
  if( null !== $week_get_row ) {

    if( $week_statistics_id == $week_get_row[2] ) {

        $c = absint( $week_get_row[4] );

        $count =  $c + 1;

        biz_visitor_statistics_update( $week_statistics_id, 'weekly_visitors', $count );
    } 

  } else {

    biz_insert_visitor_statistics_data( array(
      'statistics_id' => $week_statistics_id,
      'meta_key' => 'weekly_visitors',
      'meta_value' => 1
    ) );


  }
  
  // update month counter
    
  if( null !== $month_get_row ) {

    if( $month_statistics_id == $month_get_row[2] ) {

        $c = absint( $month_get_row[4] );

        $count =  $c + 1;

        biz_visitor_statistics_update( $month_statistics_id, 'monthly_visitors', $count );
    } 
    
  } else {

    biz_insert_visitor_statistics_data( array(
      'statistics_id' => $month_statistics_id,
      'meta_key' => 'monthly_visitors',
      'meta_value' => 1
    ) );


  }


  // update year counter
  if( null !== $year_get_row ) {

    if( $year_statistics_id == $year_get_row[2] ) {

        $c = absint( $year_get_row[4] );

        $count =  $c + 1;

        biz_visitor_statistics_update( $year_statistics_id, 'yearly_visitors', $count );
    } 
    
  } else {

    biz_insert_visitor_statistics_data( array(
      'statistics_id' => $year_statistics_id,
      'meta_key' => 'yearly_visitors',
      'meta_value' => 1
    ) );


  }



}

// Init visitor count 
add_action( 'init', 'biz_visitor_count_init' );
function biz_visitor_count_init() {

  $bizrev_options = get_option( 'bizreview_options' );

  if( !empty( $bizrev_options['countswitch'] ) ) {

    $visited = 'visited';

    $expire = time()+86400;

    setcookie( 'biz_visit_time', $visited, $expire, COOKIEPATH, COOKIE_DOMAIN  );

    if( !isset( $_COOKIE['biz_visit_time'] ) ) {
      biz_visitor_count();
    }

  }

}

