<?php
namespace Bizreviewelementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;



// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Laamya elementor about page section widget.
 *
 * @since 1.0
 */
class Bizreview_Custom_Reviews extends Widget_Base {

	public function get_name() {
		return 'bizreview-custom-reviews';
	}

	public function get_title() {
		return __( 'Custom Reviews', 'bizreview' );
	}

	public function get_icon() {
		return 'eicon-review';
	}

	public function get_categories() {
		return [ 'bizreview-elements' ];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();


        // ----------------------------------------  Custom Review Settings ------------------------------
        $this->start_controls_section(
            'bizreview_custom_set',
            [
                'label' => esc_html__( 'Custom Review Settings', 'bizreview' ),
            ]
        );

        $this->add_control(
            'max_rows', [
                'label' => esc_html__( 'Max Reviews', 'bizreview' ),
                'type'  => Controls_Manager::NUMBER,
                'label_block' => true,
                'default' => '5'

            ]
        );

        $this->add_control(
            'style', [
                'label' => esc_html__( 'Style', 'bizreview' ),
                'type'  => Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '1',
                'options' => array(
                    '1'  => esc_html__( 'Style 1 (Grid)', 'bizreview' ),
                    '2'  => esc_html__( 'Style 2 (Grid)', 'bizreview' ),
                    '3'  => esc_html__( 'Style 3 (Grid)', 'bizreview' ),
                    '4'  => esc_html__( 'Style 4 (Grid)', 'bizreview' ),
                    '5'  => esc_html__( 'Style 5 (Grid)', 'bizreview' ),
                    '6'  => esc_html__( 'Style 6 (Grid)', 'bizreview' ),
                    '7'  => esc_html__( 'Style 7 (Grid)', 'bizreview' ),
                    '8'  => esc_html__( 'Style 8 (Masonary)', 'bizreview' ),
                    '9'  => esc_html__( 'Style 9 (Slider)', 'bizreview' ),
                    '10' => esc_html__( 'Style 10 (Slider)', 'bizreview' ),
                    '11' => esc_html__( 'Style 11 (Slider)', 'bizreview' ),
                    '12' => esc_html__( 'Style 12 (Slider)', 'bizreview' ),
                    '13' => esc_html__( 'Style 13 (Slider)', 'bizreview' ),
                    '14' => esc_html__( 'Style 14 (Slider)', 'bizreview' ),
                )

            ]
        );
        $this->add_control(
            'pagination',
            [
                'label' => __( 'Use Pagination', 'bizreview' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'bizreview' ),
                'label_off' => __( 'Hide', 'bizreview' ),
                'return_value' => 'yes',
                'default' => 'no',
                'condition' => [
                    'style' => ['1','2','3','4','5','6','7','8']
                ]
            ]
        );
        $this->add_control(
            'cat', [
                'label' => esc_html__( 'Reviews Category', 'bizreview' ),
                'type'  => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => bizreview_custom_review_cat()

            ]
        );

        $this->add_control(
            'padding_top', [
                'label'     => esc_html__( 'Section Padding Top', 'bizreview' ),
                'type'      => Controls_Manager::NUMBER,
                'default'   => '50'
            ]
        );
        $this->add_control(
            'padding_bottom', [
                'label'     => esc_html__( 'Section Padding Bottom', 'bizreview' ),
                'type'      => Controls_Manager::NUMBER,
                'default'   => '50'
            ]
        );
        $this->add_control(
            'bg_color', [
                'label'     => esc_html__( 'Section Background Color', 'bizreview' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#fff'
            ]
        );

        $this->end_controls_section(); // End section top content

	}

	protected function render() {

        $settings = $this->get_settings();

        bizreview_custom_review_template_init( $settings );


    }
	
}
