<?php
namespace Bizreviewelementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;



// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Laamya elementor about page section widget.
 *
 * @since 1.0
 */
class Bizreview_Social_Slider_Badges extends Widget_Base {

	public function get_name() {
		return 'bizreview-social-slider-badges';
	}

	public function get_title() {
		return __( 'Review Badges Slider', 'bizreview' );
	}

	public function get_icon() {
		return 'eicon-rating';
	}

	public function get_categories() {
		return [ 'bizreview-elements' ];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();


        // ----------------------------------------  Custom Review Settings ------------------------------
        $this->start_controls_section(
            'bizreview_badges_set',
            [
                'label' => esc_html__( 'Social Badges Settings', 'bizreview' ),
            ]
        );
        $this->add_control(
			'section_padding',
			[
				'label' => __( 'Padding', 'bizreview' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .review-section' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
        );
        $this->add_control(
            'color_text', [
                'label' => __( 'Text Color', 'bizreview' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#000',    
                'selectors' => [
                    '{{WRAPPER}} .badges-wrapper .badges-inner .title-img h3' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .badges-footer span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'sectionoverlaybg',
                'label' => __( 'Background', 'bizreview' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .review-section'
            ]
        );

        $this->end_controls_section(); // End section top content

	}

	protected function render() {

    $settings = $this->get_settings();


        // Get Reviews Badges
        $postArgs = array(
            'post_type' => 'reviewbadges',
            'posts_per_page' => '-1'
        );

        $badges = new \WP_Query( $postArgs );

        if( $badges->have_posts() ):
            echo '<section class="review-section">';
            echo '<div class="container"><div class="row"><div class="bt-slide-2 slide-badges bt-mid-control owl-carousel owl-theme">';
            while( $badges->have_posts() ):
                $badges->the_post();

                $postID = get_the_ID();

                $platform        = get_post_meta( $postID, 'bizreviewbadges_platform', true );
                $name       	 = get_post_meta( $postID, 'bizreviewplarform_name', true );
                $pic       		 = get_post_meta( $postID, 'bizreviewplatform_pic', true );
                $ratings      	 = get_post_meta( $postID, 'bizreviewratings', true );
                $totalReview     = get_post_meta( $postID, 'bizreviewtotal_reviews', true );
                $reviewUrl       = get_post_meta( $postID, 'bizreviewreviews_url', true );

                $img = wp_get_attachment_image_src( $pic, 'full' );
        ?>
        <div class="col-sm-12">
            <div class="badges-wrapper">
                <div class="badges-inner">
                    <div class="title-img">
                        <?php
                            //
                            if( ! empty( $img[0] ) ) {
                                echo '<img class="badges-img" src="'.esc_url( $img[0] ).'" alt="'.esc_attr( $name ).'" />';
                            }
                            // Title
                            if( ! empty( $name ) ) {
                                echo '<h3>'.esc_html( $name ).'</h3>';
                            }
                        ?>
                    </div>
                    <div class="rating <?php echo esc_html( $platform ); ?>">
                    <?php 
                    //
                    if( ! empty( $ratings ) ) {
                        echo '<span>'.esc_html( $ratings ).'</span>';
                        echo '<span>'.bizreview_star_review( esc_html( $ratings ) ).'</span>';
                    }
                    //
                    ?>
                    </div>
                    <div class="badges-footer">
                        <?php
                        //
                        if( ! empty( $totalReview ) ) {
                            echo '<span>'.sprintf( esc_html__( 'Based on %s reviews', 'bizreview' ), esc_html( $totalReview ) ).'</span>';
                        } 
                        //
                        if( ! empty( $reviewUrl ) ) {
                            echo '<span><a href="'.esc_url( $reviewUrl ).'" target="_blank">'.esc_html__( 'View Review', 'bizreview' ).'</a></span>';
                        }
                        ?>
                    </div>
                </div>
            </div>
        </div>
        <?php 
        endwhile;
        echo '</div></div></div>';
        echo '</div>';
        endif;
        ?>
    <?php
    }
	
}
